@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright (C) 2020 Dremio
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -70,7 +68,7 @@ class Content:
 
     def pretty_print(self) -> str:
         """Print out for cli."""
-        pass
+        raise NotImplementedError
 
 
 @attr.dataclass
@@ -211,7 +209,7 @@ class Operation:
 
     def pretty_print(self) -> str:
         """Print out for cli."""
-        pass
+        raise NotImplementedError
 
 
 @attr.dataclass
@@ -247,7 +245,10 @@ DeleteOperationSchema = desert.schema_class(Delete)
 class Unchanged(Operation):
     """Unchanged single key."""
 
-    pass
+    def pretty_print(self) -> str:
+        """Print out for cli."""
+        # pylint: disable=E1101
+        return f"Unchanged of {self.key.to_string()}"
 
 
 UnchangedOperationSchema = desert.schema_class(Unchanged)
@@ -278,9 +279,9 @@ class OperationsSchema(OneOfSchema):
 class CommitMeta:
     """Dataclass for commit metadata."""
 
-    hash_: str = desert.ib(fields.Str(data_key="hash"), default=None)
-    commitTime: datetime = desert.ib(fields.DateTime(), default=None)
-    authorTime: datetime = desert.ib(fields.DateTime(), default=None)
+    hash_: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(data_key="hash")))
+    commitTime: datetime = attr.ib(default=None, metadata=desert.metadata(fields.DateTime()))
+    authorTime: datetime = attr.ib(default=None, metadata=desert.metadata(fields.DateTime()))
     committer: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
     author: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
     signedOffBy: str = attr.ib(default=None, metadata=desert.metadata(fields.Str(allow_none=True)))
@@ -442,6 +443,9 @@ class Transplant:
 
     from_ref_name: str = attr.ib(metadata=desert.metadata(fields.Str(data_key="fromRefName")))
     hashes_to_transplant: List[str] = attr.ib(metadata=desert.metadata(fields.List(fields.Str(), data_key="hashesToTransplant")))
+    keep_individual_commits: bool = attr.ib(
+        default=True, metadata=desert.metadata(fields.Bool(allow_none=True, data_key="keepIndividualCommits"))
+    )
 
 
 TransplantSchema = desert.schema_class(Transplant)
@@ -458,6 +462,45 @@ class Merge:
 MergeSchema = desert.schema_class(Merge)
 
 
+@attr.dataclass
+class MergeResponseDetails:
+    """Dataclass for details in MergeResponse."""
+
+    key: ContentKey = attr.ib(metadata=desert.metadata(fields.Nested(ContentKeySchema())))
+    merge_behaviour: str = attr.ib(metadata=desert.metadata(fields.Str(data_key="mergeBehavior")))
+    conflict_type: str = attr.ib(metadata=desert.metadata(fields.Str(data_key="conflictType")))
+    source_commits: List[str] = attr.ib(metadata=desert.metadata(fields.List(fields.Str(), data_key="sourceCommits")))
+    target_commits: List[str] = attr.ib(metadata=desert.metadata(fields.List(fields.Str(allow_none=True), data_key="targetCommits")))
+
+
+MergeResponseDetailsSchema = desert.schema_class(MergeResponseDetails)
+
+
+@attr.dataclass
+class MergeResponse:
+    """Dataclass for a MergeResponse."""
+
+    target_branch: str = attr.ib(metadata=desert.metadata(fields.Str(data_key="targetBranch")))
+    effective_target_hash: str = attr.ib(metadata=desert.metadata(fields.Str(data_key="effectiveTargetHash")))
+    source_commits: List[LogEntry] = attr.ib(
+        metadata=desert.metadata(fields.List(fields.Nested(LogEntrySchema()), data_key="sourceCommits"))
+    )
+    details: List[MergeResponseDetails] = attr.ib(
+        metadata=desert.metadata(fields.List(fields.Nested(MergeResponseDetailsSchema()), data_key="details"))
+    )
+    resultant_target_hash: str = attr.ib(metadata=desert.metadata(fields.Str(allow_none=True, data_key="resultantTargetHash")))
+    common_ancestor: str = attr.ib(metadata=desert.metadata(fields.Str(allow_none=True, data_key="commonAncestor")))
+    expected_hash: str = attr.ib(metadata=desert.metadata(fields.Str(allow_none=True, data_key="expectedHash")))
+    target_commits: List[LogEntry] = attr.ib(
+        metadata=desert.metadata(fields.List(fields.Nested(LogEntrySchema()), allow_none=True, data_key="targetCommits"))
+    )
+    was_applied: bool = attr.ib(default=False, metadata=desert.metadata(fields.Bool(data_key="wasApplied")))
+    was_successful: bool = attr.ib(default=False, metadata=desert.metadata(fields.Bool(data_key="wasSuccessful")))
+
+
+MergeResponseSchema = desert.schema_class(MergeResponse)
+
+
 @attr.dataclass
 class MultiContents:
     """Contents container for commit."""
