@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
 # Copyright (C) 2020 Dremio
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -36,6 +33,7 @@ from pynessie.model import (
     IcebergTable,
     LogEntry,
     LogEntrySchema,
+    MergeResponseSchema,
     ReferenceSchema,
     ReflogEntry,
     ReflogEntrySchema,
@@ -157,7 +155,7 @@ def test_log() -> None:
             "nessie_user2",
         ],
     )
-    assert_that(simplejson.loads(execute_cli_command(["--json", "log", "-n", 1]))).is_length(1)
+    assert_that(simplejson.loads(execute_cli_command(["--json", "log", "-n", "1"]))).is_length(1)
     assert_that(simplejson.loads(execute_cli_command(["--json", "log", "dev_test_log"]))).is_length(1)
     logs = simplejson.loads(execute_cli_command(["--json", "log"]))
     assert_that(logs).is_length(2)
@@ -314,16 +312,80 @@ def test_merge() -> None:
 
     # Passing detached commit-id plus a _different_ hash-on-ref --> error
     execute_cli_command(["merge", f"dev@{dev_hash}", "-c", main_hash, "-o", main_hash], ret_val=1)
+    merge_output = execute_cli_command(["merge", "dev", "-c", main_hash])
+
+    branches = ReferenceSchema().loads(execute_cli_command(["--json", "branch"]), many=True)
+    refs = {i.name: i.hash_ for i in branches}
+
+    expected_output_list = [
+        "The following 1 commits were merged onto main:",
+        '{} "test message" '.format(refs["dev"]),
+        "Resultant hash on main after merge: {}".format(refs["main"]),
+    ]
+    assert_that(merge_output.splitlines()).is_equal_to(expected_output_list)
+
+    # if we try to merge again from dev to main we get an error
+    # this is because there is now a conflict as the same commit exists on both branches
+    merge_error = execute_cli_command(["merge", "dev", "-c", refs["main"]], ret_val=1)
+    assert "Client Error Conflict: The following keys have been changed in conflict:" in merge_error
 
-    execute_cli_command(["merge", "dev", "-c", main_hash])
     logs = simplejson.loads(execute_cli_command(["--json", "log"]))
     # we don't check for equality of hashes here because a merge
     # produces a different commit hash on the target branch
     assert len(logs) == 1
+    assert_that(logs[0]["message"]).is_equal_to("test message")
     logs = simplejson.loads(execute_cli_command(["--json", "log", "dev"]))
     assert len(logs) == 1
 
 
+@pytest.mark.vcr
+def test_merge_json() -> None:
+    """Test merge operation."""
+    execute_cli_command(["branch", "dev"])
+    make_commit("merge.foo.bar", _new_table("test_merge"), "dev")
+    main_hash = ref_hash("main")
+    dev_hash = ref_hash("dev")
+
+    # Passing detached commit-id plus a _different_ hash-on-ref --> error
+    execute_cli_command(["merge", f"dev@{dev_hash}", "-c", main_hash, "-o", main_hash], ret_val=1)
+
+    merge_output = execute_cli_command(["--json", "merge", "dev", "-c", main_hash])
+    merge_response = MergeResponseSchema().loads(merge_output)
+
+    # Check merge response
+    assert_that(merge_response.target_branch).is_equal_to("main")
+    assert_that(merge_response.expected_hash).is_equal_to(main_hash)
+    assert_that(merge_response.effective_target_hash).is_equal_to(main_hash)
+    assert len(merge_response.source_commits) == 1
+    assert len(merge_response.details) == 1
+    assert_that(merge_response.details[0].source_commits[0]).is_equal_to(dev_hash)
+
+    logs = simplejson.loads(execute_cli_command(["--json", "log"]))
+    # we don't check for equality of hashes here because a merge
+    # produces a different commit hash on the target branch
+    assert len(logs) == 1
+    assert_that(logs[0]["message"]).is_equal_to("test message")
+    logs = simplejson.loads(execute_cli_command(["--json", "log", "dev"]))
+    assert len(logs) == 1
+
+
+@pytest.mark.vcr
+def test_merge_legacy() -> None:
+    """Test merge operation."""
+    execute_cli_command(["branch", "dev"])
+    make_commit("merge.foo.bar", _new_table("test_merge"), "dev")
+    main_hash = ref_hash("main")
+
+    merge_output = execute_cli_command(["merge", "dev", "-c", main_hash])
+    assert_that(merge_output).is_equal_to("Merge succeeded but legacy server did not respond with additional details.\n")
+
+    execute_cli_command(["branch", "devjson"])
+    make_commit("merge.foo.far", _new_table("test_merge_json"), "devjson")
+
+    merge_output = execute_cli_command(["--json", "merge", "-f", "-b", "main", "devjson"])
+    assert_that(merge_output).is_equal_to('{"_cli_hint": "Merge succeeded but legacy server did not respond with additional details."}\n')
+
+
 @pytest.mark.vcr
 def test_merge_detached() -> None:
     """Test merge operation."""
@@ -335,11 +397,54 @@ def test_merge_detached() -> None:
     # Passing detached commit-id plus a _different_ hash-on-ref --> error
     execute_cli_command(["merge", dev_hash, "-c", main_hash, "-o", main_hash], ret_val=1)
 
-    execute_cli_command(["merge", dev_hash, "-c", main_hash])
+    merge_output = execute_cli_command(["merge", "dev", "-c", main_hash])
+
+    branches = ReferenceSchema().loads(execute_cli_command(["--json", "branch"]), many=True)
+    refs = {i.name: i.hash_ for i in branches}
+
+    expected_output_list = [
+        "The following 1 commits were merged onto main:",
+        '{} "test message" '.format(refs["dev"]),
+        "Resultant hash on main after merge: {}".format(refs["main"]),
+    ]
+    assert_that(merge_output.splitlines()).is_equal_to(expected_output_list)
+
     logs = simplejson.loads(execute_cli_command(["--json", "log"]))
     # we don't check for equality of hashes here because a merge
     # produces a different commit hash on the target branch
     assert len(logs) == 1
+    assert_that(logs[0]["message"]).is_equal_to("test message")
+    logs = simplejson.loads(execute_cli_command(["--json", "log", "dev"]))
+    assert len(logs) == 1
+
+
+@pytest.mark.vcr
+def test_merge_detached_json() -> None:
+    """Test merge operation."""
+    execute_cli_command(["branch", "dev"])
+    make_commit("merge.foo.bar", _new_table("test_merge_detached"), "dev")
+    main_hash = ref_hash("main")
+    dev_hash = ref_hash("dev")
+
+    # Passing detached commit-id plus a _different_ hash-on-ref --> error
+    execute_cli_command(["merge", dev_hash, "-c", main_hash, "-o", main_hash], ret_val=1)
+
+    merge_output = execute_cli_command(["--json", "merge", dev_hash, "-c", main_hash])
+    merge_response = MergeResponseSchema().loads(merge_output)
+
+    # Check merge response
+    assert_that(merge_response.target_branch).is_equal_to("main")
+    assert_that(merge_response.expected_hash).is_equal_to(main_hash)
+    assert_that(merge_response.effective_target_hash).is_equal_to(main_hash)
+    assert len(merge_response.source_commits) == 1
+    assert len(merge_response.details) == 1
+    assert_that(merge_response.details[0].source_commits[0]).is_equal_to(dev_hash)
+
+    logs = simplejson.loads(execute_cli_command(["--json", "log"]))
+    # we don't check for equality of hashes here because a merge
+    # produces a different commit hash on the target branch
+    assert len(logs) == 1
+    assert_that(logs[0]["message"]).is_equal_to("test message")
     logs = simplejson.loads(execute_cli_command(["--json", "log", "dev"]))
     assert len(logs) == 1
 
@@ -348,9 +453,9 @@ def test_merge_detached() -> None:
 def test_transplant() -> None:
     """Test transplant operation."""
     execute_cli_command(["branch", "dev"])
-    make_commit("transplant.foo.bar", _new_table("test_transplant_1"), "dev")
-    make_commit("bar.bar", _new_table("test_transplant_2"), "dev")
-    make_commit("foo.baz", _new_table("test_transplant_3"), "dev")
+    make_commit("transplant.foo.bar", _new_table("test_transplant_1"), "dev", message="commit 1")
+    make_commit("bar.bar", _new_table("test_transplant_2"), "dev", message="commit 2")
+    make_commit("foo.baz", _new_table("test_transplant_3"), "dev", message="commit 3")
     main_hash = ref_hash("main")
     logs = simplejson.loads(execute_cli_command(["--json", "log", "dev"]))
     first_hash = [i["hash"] for i in logs]
@@ -358,6 +463,8 @@ def test_transplant() -> None:
 
     logs = simplejson.loads(execute_cli_command(["--json", "log"]))
     assert len(logs) == 2  # two commits were transplanted into an empty `main`
+    assert_that(logs[0]["message"]).is_equal_to("commit 3")
+    assert_that(logs[1]["message"]).is_equal_to("commit 2")
 
 
 @pytest.mark.vcr
@@ -417,7 +524,7 @@ def test_reflog() -> None:
     # validate the entries
     assert_that(response_entries[0:5]).extracting("ref_name", "operation").is_equal_to(expected_entries)
     # test pagination
-    response_entries_1: List[ReflogEntry] = ReflogEntrySchema().loads(execute_cli_command(["--json", "reflog", "-n", 2]), many=True)
+    response_entries_1: List[ReflogEntry] = ReflogEntrySchema().loads(execute_cli_command(["--json", "reflog", "-n", "2"]), many=True)
     assert_that(response_entries[0:2]).is_equal_to(response_entries_1)
     # test start hash (closer to the head)
     response_entries_2: List[ReflogEntry] = ReflogEntrySchema().loads(
